"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSiteEditorNavigationCommands = useSiteEditorNavigationCommands;

var _commands = require("@wordpress/commands");

var _i18n = require("@wordpress/i18n");

var _element = require("@wordpress/element");

var _data = require("@wordpress/data");

var _coreData = require("@wordpress/core-data");

var _icons = require("@wordpress/icons");

var _router = require("@wordpress/router");

var _url = require("@wordpress/url");

var _lockUnlock = require("./lock-unlock");

/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */
const {
  useCommandLoader
} = (0, _lockUnlock.unlock)(_commands.privateApis);
const {
  useHistory
} = (0, _lockUnlock.unlock)(_router.privateApis);
const icons = {
  post: _icons.post,
  page: _icons.page,
  wp_template: _icons.layout,
  wp_template_part: _icons.symbolFilled
};

const getNavigationCommandLoaderPerPostType = postType => function useNavigationCommandLoader(_ref) {
  let {
    search
  } = _ref;
  const history = useHistory();
  const supportsSearch = !['wp_template', 'wp_template_part'].includes(postType);
  const deps = supportsSearch ? [search] : [];
  const {
    records,
    isLoading
  } = (0, _data.useSelect)(select => {
    const {
      getEntityRecords
    } = select(_coreData.store);
    const query = supportsSearch ? {
      search: !!search ? search : undefined,
      per_page: 10,
      orderby: search ? 'relevance' : 'date'
    } : {
      per_page: -1
    };
    return {
      records: getEntityRecords('postType', postType, query),
      isLoading: !select(_coreData.store).hasFinishedResolution('getEntityRecords', ['postType', postType, query]),
      // We're using the string literal to check whether we're in the site editor.

      /* eslint-disable-next-line @wordpress/data-no-store-string-literals */
      isSiteEditor: !!select('edit-site')
    };
  }, deps);
  const commands = (0, _element.useMemo)(() => {
    return (records !== null && records !== void 0 ? records : []).slice(0, 10).map(record => {
      var _getPath, _record$title, _record$title2, _record$title3;

      const isSiteEditor = (_getPath = (0, _url.getPath)(window.location.href)) === null || _getPath === void 0 ? void 0 : _getPath.includes('site-editor.php');
      const extraArgs = isSiteEditor ? {
        canvas: (0, _url.getQueryArg)(window.location.href, 'canvas')
      } : {};
      return {
        name: ((_record$title = record.title) === null || _record$title === void 0 ? void 0 : _record$title.rendered) + ' ' + record.id,
        label: (_record$title2 = record.title) !== null && _record$title2 !== void 0 && _record$title2.rendered ? (_record$title3 = record.title) === null || _record$title3 === void 0 ? void 0 : _record$title3.rendered : (0, _i18n.__)('(no title)'),
        icon: icons[postType],
        callback: _ref2 => {
          let {
            close
          } = _ref2;
          const args = {
            postType,
            postId: record.id,
            ...extraArgs
          };
          const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);

          if (isSiteEditor) {
            history.push(args);
          } else {
            document.location = targetUrl;
          }

          close();
        }
      };
    });
  }, [records, history]);
  return {
    commands,
    isLoading
  };
};

const usePageNavigationCommandLoader = getNavigationCommandLoaderPerPostType('page');
const usePostNavigationCommandLoader = getNavigationCommandLoaderPerPostType('post');
const useTemplateNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template');
const useTemplatePartNavigationCommandLoader = getNavigationCommandLoaderPerPostType('wp_template_part');

function useSiteEditorNavigationCommands() {
  useCommandLoader({
    name: 'core/edit-site/navigate-pages',
    group: (0, _i18n.__)('Pages'),
    hook: usePageNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-posts',
    group: (0, _i18n.__)('Posts'),
    hook: usePostNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-templates',
    group: (0, _i18n.__)('Templates'),
    hook: useTemplateNavigationCommandLoader
  });
  useCommandLoader({
    name: 'core/edit-site/navigate-template-parts',
    group: (0, _i18n.__)('Template Parts'),
    hook: useTemplatePartNavigationCommandLoader
  });
}
//# sourceMappingURL=site-editor-navigation-commands.js.map